;**********************************
;  This file is part of
; "Simple SEGA Master System BIOS" 
;  By David Senabre Albujer.
;
;  Print to screen routines.
;
; Assembler: WLA_DX
;**********************************

    ;===============================
    ; Rutinas de escritura en pantalla
    ;===============================
.section "Print routines" free
;---------------------------------------
PrintScreen:
; bc: origen
;---------------------------------------
push hl
push af
push bc
    ld hl,NameTableAddress
    call VRAMToHL
    -:
        ld a,(bc)    ; cargar nuevo byte a escribir
        cp $00       ; si es cero es que hemos llegado al final
        jp z,+       ;
        out ($be),a
        ld a,$00
        out ($be),a
        inc bc       ; apuntar al siguiente byte
        jp -
    +:
pop bc
pop af
pop hl
ret

;-------------------------------------------------------------
PrintScreenExt:
; hl: NameTable offset
; d: numero de caracteres
; bc: origen
;-------------------------------------------------------------
push af
push bc
push hl
push de
    ld de,NameTableAddress
    add hl,de
    call VRAMToHL
    pop de
    push de
    -:
        ld a,(bc)    ; cargar nuevo byte a escribir
        cp $00       ; si es cero es que hemos llegado al final
        jp z,+       ;
        out ($be),a
        ld a,$00
        out ($be),a
        inc bc       ; apuntar al siguiente byte
        dec d
        jp nz,-
    +:
pop de
pop hl
pop bc
pop af
ret

    ;---------------------------------------

ClearScreen:
push hl
push af
    ld hl,NameTableAddress
    call VRAMToHL
    ld bc,28*32
    -:
    ld a,$0
    out ($be),a
    ld a,$0
    out ($be),a
    dec bc
    ld a,b
    or c
    jp nz,-
pop af
pop hl
ret

;******************************************
; Ambas rutinas configuran :
; 8x8 sprites.
; 24 rows/192 lines mode
; INT VBlank desactivada

ScreenOff:
push af
    ld a,%10000100
    out ($bf),a
    ld a,$81
    out ($bf),a
pop af
ret

ScreenOn:
push af
    ld a,%11000100
    out ($bf),a
    ld a,$81
    out ($bf),a
pop af
ret
;******************************************
    ;---------------------------------------
    ; borra una linea de tiles en pantalla
    ;---------------------------------------
DeleteLine:
  push hl
    ld h,b
    ld l,c
    call VRAMToHL
    ld bc,64
    add hl, bc
    ld b,h
    ld c,l
  push bc
    ld c,32
  -:
    out ($be),a
    out ($be),a
    dec c
    jp nz,-
  pop bc
  pop hl
ret


;---------------------------------------
; Escribe si la consola es japonesa o no
;---------------------------------------
PrintDomesticMode:
  push af
  push bc
  push hl
  push de
    ld a,(DomesticMode)
    bit 0,a
    jp z,+
    ld bc,DomesticString
    jp ++
    +:
    ld bc,ExportString
    ++:
    ld hl,64*14
    ld d,255
    call PrintScreenExt
  pop de
  pop hl
  pop bc
  pop af
ret

;---------------------------------------
; Escribe si la TV es PAL o NTSC
;---------------------------------------
PrintTVMode:
  push af
  push bc
  push hl
  push de
    ld a,(NTSCMode)
    bit 0,a
    jp z,+
    ld bc,PALString
    jp ++
    +:
    ld bc,NTSCString
    ++:
    ld hl,64*15
    ld d,255
    call PrintScreenExt
  pop de
  pop hl
  pop bc
  pop af
ret

;---------------------------------------
PrintCart:
;---------------------------------------
  push bc
  push hl
  push de
    ;--------------------
    ld a,(CartIn)
    bit 0,a
    jp z,+
    ;cartucho si insertado
    ld bc,CartInString
    jp ++
   +:
    ;cartucho no insertado
    ld bc,CartNotInString
  ++:
    ld hl,64*19
    ld d,32
    call PrintScreenExt

    ;--------------------
    ld a,(GameIn)
    bit 0,a
    jp z,+
    ;cartucho si insertado
    ld bc,GameInString
    jp ++
   +:
    ;cartucho no insertado
    ld bc,GameNotInString
  ++:
    ld hl,64*20
    ld d,32
    call PrintScreenExt

  pop de
  pop hl
  pop bc
ret

PrintSEGA:
  push bc
  push hl
  push de
    ld hl,960
    ld d,8
    ld bc,String1
    call PrintScreenExt
  pop de
  pop hl
  pop bc
ret


.ends